==> org.apache.sling.testing.resourceresolver-mock-1.4.6-source-release.zip: org.apache.sling.testing.resourceresolver-mock-1.4.6/src/test/java/org/apache/sling/testing/resourceresolver/FindQueryResourcesResourceResolverFactoryOptionsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.testing.resourceresolver;

import java.util.Arrays;

import org.apache.sling.api.resource.LoginException;
import org.apache.sling.api.resource.ResourceResolver;
import org.apache.sling.testing.mock.sling.ResourceResolverType;
import org.apache.sling.testing.mock.sling.junit.SlingContext;
import org.junit.Rule;

public class FindQueryResourcesResourceResolverFactoryOptionsTest extends FindQueryResourcesTest {

    @Rule
    public SlingContext context = new SlingContext(ResourceResolverType.NONE);

    @Override
    protected ResourceResolver createResourceResolver_addFindResourceHandlers(MockFindResourcesHandler... handlers) throws LoginException {
        // set handler on other resource resolver created in setUp
        Arrays.stream(handlers).forEach(handler -> MockFindQueryResources.addFindResourceHandler(resourceResolver, handler));
        return createResourceResolver();
    }

    @Override
    protected ResourceResolver createResourceResolver_addQueryResourceHandlers(MockQueryResourceHandler... handlers) throws LoginException {
        // set handler on other resource resolver created in setUp
        Arrays.stream(handlers).forEach(handler -> MockFindQueryResources.addQueryResourceHandler(resourceResolver, handler));
        return createResourceResolver();
    }

}

==> org.apache.sling.testing.resourceresolver-mock-2.0.0-source-release.zip: org.apache.sling.testing.resourceresolver-mock-2.0.0/src/test/java/org/apache/sling/testing/resourceresolver/FindQueryResourcesResourceResolverFactoryOptionsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.testing.resourceresolver;

import java.util.Arrays;

import org.apache.sling.api.resource.LoginException;
import org.apache.sling.api.resource.ResourceResolver;
import org.apache.sling.testing.mock.sling.ResourceResolverType;
import org.apache.sling.testing.mock.sling.junit.SlingContext;
import org.junit.Rule;

public class FindQueryResourcesResourceResolverFactoryOptionsTest extends FindQueryResourcesTest {

    @Rule
    public SlingContext context = new SlingContext(ResourceResolverType.NONE);

    @Override
    protected ResourceResolver createResourceResolver_addFindResourceHandlers(MockFindResourcesHandler... handlers)
            throws LoginException {
        // set handler on other resource resolver created in setUp
        Arrays.stream(handlers)
                .forEach(handler -> MockFindQueryResources.addFindResourceHandler(resourceResolver, handler));
        return createResourceResolver();
    }

    @Override
    protected ResourceResolver createResourceResolver_addQueryResourceHandlers(MockQueryResourceHandler... handlers)
            throws LoginException {
        // set handler on other resource resolver created in setUp
        Arrays.stream(handlers)
                .forEach(handler -> MockFindQueryResources.addQueryResourceHandler(resourceResolver, handler));
        return createResourceResolver();
    }
}
